Version 1.0.1
-------------

* Use jQuery live events to support using the ``AnyUrlField`` in Django inlines.


Version 1.0.0
-------------

First PyPI release.

The module design has been stable for quite some time,
so it's time to release this module to the public.
